/*
* @fileOverview TouchSwipe - jQuery Plugin
* @version 1.6.5
*
* @author Matt Bryson http://www.github.com/mattbryson
* @see https://github.com/mattbryson/TouchSwipe-Jquery-Plugin
* @see http://labs.skinkers.com/touchSwipe/
* @see http://plugins.jquery.com/project/touchSwipe
*
* Copyright (c) 2010 Matt Bryson
* Dual licensed under the MIT or GPL Version 2 licenses.
*
*
* Changelog
* $Date: 2010-12-12 (Wed, 12 Dec 2010) $
* $version: 1.0.0
* $version: 1.0.1 - removed multibyte comments
*
* $Date: 2011-21-02 (Mon, 21 Feb 2011) $
* $version: 1.1.0         - added allowPageScroll property to allow swiping and scrolling of page
*                                        - changed handler signatures so one handler can be used for multiple events
* $Date: 2011-23-02 (Wed, 23 Feb 2011) $
* $version: 1.2.0         - added click handler. This is fired if the user simply clicks and does not swipe. The event object and click target are passed to handler.
*                                        - If you use the http://code.google.com/p/jquery-ui-for-ipad-and-iphone/ plugin, you can also assign jQuery mouse events to children of a touchSwipe object.
* $version: 1.2.1         - removed console log!
*
* $version: 1.2.2         - Fixed bug where scope was not preserved in callback methods.
*
* $Date: 2011-28-04 (Thurs, 28 April 2011) $
* $version: 1.2.4         - Changed licence terms to be MIT or GPL inline with jQuery. Added check for support of touch events to stop non compatible browsers erroring.
*
* $Date: 2011-27-09 (Tues, 27 September 2011) $
* $version: 1.2.5         - Added support for testing swipes with mouse on desktop browser (thanks to https://github.com/joelhy)
*
* $Date: 2012-14-05 (Mon, 14 May 2012) $
* $version: 1.2.6         - Added timeThreshold between start and end touch, so user can ignore slow swipes (thanks to Mark Chase). Default is null, all swipes are detected
*
* $Date: 2012-05-06 (Tues, 05 June 2012) $
* $version: 1.2.7         - Changed time threshold to have null default for backwards compatibility. Added duration param passed back in events, and refactored how time is handled.
*
* $Date: 2012-05-06 (Tues, 05 June 2012) $
* $version: 1.2.8         - Added the possibility to return a value like null or false in the trigger callback. In that way we can control when the touch start/move should take effect or not (simply by returning in some cases return null; or return false;) This effects the ontouchstart/ontouchmove event.
*
* $Date: 2012-06-06 (Wed, 06 June 2012) $
* $version: 1.3.0         - Refactored whole plugin to allow for methods to be executed, as well as exposed defaults for user override. Added 'enable', 'disable', and 'destroy' methods
*
* $Date: 2012-05-06 (Fri, 05 June 2012) $
* $version: 1.3.1         - Bug fixes - bind() with false as last argument is no longer supported in jQuery 1.6, also, if you just click, the duration is now returned correctly.
*
* $Date: 2012-29-07 (Sun, 29 July 2012) $
* $version: 1.3.2        - Added fallbackToMouseEvents option to NOT capture mouse events on non touch devices.
*                         - Added "all" fingers value to the fingers property, so any combination of fingers triggers the swipe, allowing event handlers to check the finger count
*
* $Date: 2012-09-08 (Thurs, 9 Aug 2012) $
* $version: 1.3.3        - Code tidy prep for minefied version
*
* $Date: 2012-04-10 (wed, 4 Oct 2012) $
* $version: 1.4.0        - Added pinch support, pinchIn and pinchOut
*
* $Date: 2012-11-10 (Thurs, 11 Oct 2012) $
* $version: 1.5.0        - Added excludedElements, a jquery selector that specifies child elements that do NOT trigger swipes. By default, this is one select that removes all form, input select, button and anchor elements.
*
* $Date: 2012-22-10 (Mon, 22 Oct 2012) $
* $version: 1.5.1        - Fixed bug with jQuery 1.8 and trailing comma in excludedElements
*                                        - Fixed bug with IE and eventPreventDefault()
* $Date: 2013-01-12 (Fri, 12 Jan 2013) $
* $version: 1.6.0        - Fixed bugs with pinching, mainly when both pinch and swipe enabled, as well as adding time threshold for multifinger gestures, so releasing one finger beofre the other doesnt trigger as single finger gesture.
*                                        - made the demo site all static local HTML pages so they can be run locally by a developer
*                                        - added jsDoc comments and added documentation for the plugin        
*                                        - code tidy
*                                        - added triggerOnTouchLeave property that will end the event when the user swipes off the element.
* $Date: 2013-03-23 (Sat, 23 Mar 2013) $
* $version: 1.6.1        - Added support for ie8 touch events
* $version: 1.6.2        - Added support for events binding with on / off / bind in jQ for all callback names.
* - Deprecated the 'click' handler in favour of tap.
* - added cancelThreshold property
* - added option method to update init options at runtime
*
* $version 1.6.3 - added doubletap, longtap events and longTapThreshold, doubleTapThreshold property
* $Date: 2013-04-04 (Thurs, 04 April 2013) $
* $version 1.6.4 - Fixed bug with cancelThreshold introduced in 1.6.3, where swipe status no longer fired start event, and stopped once swiping back.
*
* $Date: 2013-08-24 (Sat, 24 Aug 2013) $
* $version 1.6.5 - Merged a few pull requests fixing various bugs, added AMD support.

*/

/**
* See (http://jquery.com/).
* @name $
* @class
* See the jQuery Library (http://jquery.com/) for full details. This just
* documents the function and classes that are added to jQuery by this plug-in.
*/

/**
* See (http://jquery.com/)
* @name fn
* @class
* See the jQuery Library (http://jquery.com/) for full details. This just
* documents the function and classes that are added to jQuery by this plug-in.
* @memberOf $
*/
; (function(e) { function a(t) { e(this).touchSwipeLeft(t).touchSwipeRight(t) } function f(t) { var n = e(this); if (!n.data("swipeLeft")) n.data("swipeLeft", t); if (!n.data("swipeRight")) c(n) } function l(t) { var n = e(this); if (!n.data("swipeRight")) n.data("swipeRight", t); if (!n.data("swipeLeft")) c(n) } function c(e) { e.unbindSwipe(true).bind(r, h) } function h(r) { function m(e) { l.unbind(n); if (a && v) { if (v - a < u && Math.abs(c - p) > i && Math.abs(h - d) < s) { if (c > p) { if (l.data("swipeLeft")) l.data("swipeLeft")("left") } else { if (l.data("swipeRight")) l.data("swipeRight")("right") } } } a = v = null } function g(e) { if (a) { f = e.originalEvent.touches ? e.originalEvent.touches[0] : e; v = (new Date).getTime(); p = f.pageX; d = f.pageY; if (Math.abs(c - p) > o) e.preventDefault() } } var a = (new Date).getTime(), f = r.originalEvent.touches ? r.originalEvent.touches[0] : r, l = e(this).bind(n, g).one(t, m), c = f.pageX, h = f.pageY, p, d, v; if (l.data("stopPropagation")) r.stopImmediatePropagation() } var t, n, r, i = 30, s = 75, o = 10, u = 1e3; if ("ontouchend" in document) { t = "touchend.cj_swp"; n = "touchmove.cj_swp"; r = "touchstart.cj_swp" } else { t = "mouseup.cj_swp"; n = "mousemove.cj_swp"; r = "mousedown.cj_swp" } e.fn.touchSwipe = function(e, t) { if (t) this.data("stopPropagation", true); if (e) return this.each(a, [e]) }; e.fn.touchSwipeLeft = function(e, t) { if (t) this.data("stopPropagation", true); if (e) return this.each(f, [e]) }; e.fn.touchSwipeRight = function(e, t) { if (t) this.data("stopPropagation", true); if (e) return this.each(l, [e]) }; e.fn.unbindSwipeLeft = function() { this.removeData("swipeLeft"); if (!this.data("swipeRight")) this.unbindSwipe(true) }; e.fn.unbindSwipeRight = function() { this.removeData("swipeRight"); if (!this.data("swipeLeft")) this.unbindSwipe(true) }; e.fn.unbindSwipe = function(e) { if (!e) this.removeData("swipeLeft swipeRight stopPropagation"); return this.unbind(r + " " + n + " " + t) } })(jQuery);